# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/mdb/postgresql/v1/cluster.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/mdb/postgresql/v1/cluster.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__pb2
from yandex.cloud.mdb.postgresql.v1.config import host10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__pb2
from yandex.cloud.mdb.postgresql.v1.config import host11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__pb2
from yandex.cloud.mdb.postgresql.v1.config import host12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__pb2
from yandex.cloud.mdb.postgresql.v1.config import host13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__pb2
from yandex.cloud.mdb.postgresql.v1.config import host14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__pb2
from yandex.cloud.mdb.postgresql.v1.config import host15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__pb2
from yandex.cloud.mdb.postgresql.v1.config import host16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__pb2
from yandex.cloud.mdb.postgresql.v1.config import host17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import host9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_host9__6__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql10_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql10__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql11_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql11__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql12_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql12__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql13_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql13__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql14_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql14__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql15_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql15__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql16_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql16__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql17_1c_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql17__1c__pb2
from yandex.cloud.mdb.postgresql.v1.config import postgresql9_6_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_config_dot_postgresql9__6__pb2
from yandex.cloud.mdb.postgresql.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_postgresql_dot_v1_dot_maintenance__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/mdb/postgresql/v1/cluster.proto\x12\x1eyandex.cloud.mdb.postgresql.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host10.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host10_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host11.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host11_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host12.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host12_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host13.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host13_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host14.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host14_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host15.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host15_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host16.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host16_1c.proto\x1a\x32yandex/cloud/mdb/postgresql/v1/config/host17.proto\x1a\x35yandex/cloud/mdb/postgresql/v1/config/host17_1c.proto\x1a\x33yandex/cloud/mdb/postgresql/v1/config/host9_6.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql10.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql10_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql11.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql11_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql12.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql12_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql13.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql13_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql14.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql14_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql15.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql15_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql16.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql16_1c.proto\x1a\x38yandex/cloud/mdb/postgresql/v1/config/postgresql17.proto\x1a;yandex/cloud/mdb/postgresql/v1/config/postgresql17_1c.proto\x1a\x39yandex/cloud/mdb/postgresql/v1/config/postgresql9_6.proto\x1a\x30yandex/cloud/mdb/postgresql/v1/maintenance.proto\x1a\x1dyandex/cloud/validation.proto\"\xc4\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x43\n\x06labels\x18\x06 \x03(\x0b\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.LabelsEntry\x12H\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.mdb.postgresql.v1.Cluster.Environment\x12>\n\nmonitoring\x18\x08 \x03(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.Monitoring\x12=\n\x06\x63onfig\x18\t \x01(\x0b\x32-.yandex.cloud.mdb.postgresql.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12>\n\x06health\x18\x0b \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Cluster.Health\x12>\n\x06status\x18\x0c \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Cluster.Status\x12M\n\x12maintenance_window\x18\r \x01(\x0b\x32\x31.yandex.cloud.mdb.postgresql.v1.MaintenanceWindow\x12O\n\x11planned_operation\x18\x0e \x01(\x0b\x32\x34.yandex.cloud.mdb.postgresql.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x0f \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x10 \x01(\x08\x12\x16\n\x0ehost_group_ids\x18\x11 \x03(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xd2\x14\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12t\n\x15postgresql_config_9_6\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet9_6H\x00R\x14postgresqlConfig_9_6\x12z\n\x17postgresql_config_10_1c\x18\n \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet10_1CH\x00R\x16postgresqlConfig_10_1c\x12q\n\x14postgresql_config_10\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet10H\x00R\x13postgresqlConfig_10\x12q\n\x14postgresql_config_11\x18\x08 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet11H\x00R\x13postgresqlConfig_11\x12z\n\x17postgresql_config_11_1c\x18\r \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet11_1CH\x00R\x16postgresqlConfig_11_1c\x12q\n\x14postgresql_config_12\x18\x0b \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet12H\x00R\x13postgresqlConfig_12\x12z\n\x17postgresql_config_12_1c\x18\x0e \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet12_1CH\x00R\x16postgresqlConfig_12_1c\x12q\n\x14postgresql_config_13\x18\x0f \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13H\x00R\x13postgresqlConfig_13\x12z\n\x17postgresql_config_13_1c\x18\x12 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet13_1CH\x00R\x16postgresqlConfig_13_1c\x12q\n\x14postgresql_config_14\x18\x10 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet14H\x00R\x13postgresqlConfig_14\x12z\n\x17postgresql_config_14_1c\x18\x13 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet14_1CH\x00R\x16postgresqlConfig_14_1c\x12q\n\x14postgresql_config_15\x18\x15 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet15H\x00R\x13postgresqlConfig_15\x12z\n\x17postgresql_config_15_1c\x18\x16 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet15_1CH\x00R\x16postgresqlConfig_15_1c\x12q\n\x14postgresql_config_16\x18\x18 \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet16H\x00R\x13postgresqlConfig_16\x12z\n\x17postgresql_config_16_1c\x18\x19 \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet16_1CH\x00R\x16postgresqlConfig_16_1c\x12q\n\x14postgresql_config_17\x18\x1b \x01(\x0b\x32<.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet17H\x00R\x13postgresqlConfig_17\x12z\n\x17postgresql_config_17_1c\x18\x1c \x01(\x0b\x32?.yandex.cloud.mdb.postgresql.v1.config.PostgresqlConfigSet17_1CH\x00R\x16postgresqlConfig_17_1c\x12M\n\rpooler_config\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.ConnectionPoolerConfig\x12<\n\tresources\x18\x05 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Resources\x12\x30\n\x0c\x61utofailover\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x07 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12H\n\x19\x62\x61\x63kup_retain_period_days\x18\x11 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x37-60\x12\x36\n\x06\x61\x63\x63\x65ss\x18\t \x01(\x0b\x32&.yandex.cloud.mdb.postgresql.v1.Access\x12W\n\x17performance_diagnostics\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.mdb.postgresql.v1.PerformanceDiagnostics\x12R\n\x15\x64isk_size_autoscaling\x18\x17 \x01(\x0b\x32\x33.yandex.cloud.mdb.postgresql.v1.DiskSizeAutoscalingB\x13\n\x11postgresql_configJ\x04\x08\x14\x10\x15J\x04\x08\x1a\x10\x1b\"\xfe\x01\n\x16\x43onnectionPoolerConfig\x12X\n\x0cpooling_mode\x18\x01 \x01(\x0e\x32\x42.yandex.cloud.mdb.postgresql.v1.ConnectionPoolerConfig.PoolingMode\x12\x30\n\x0cpool_discard\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"X\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x12\r\n\tSTATEMENT\x10\x03\"\xf0\x05\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12<\n\tresources\x18\x04 \x01(\x0b\x32).yandex.cloud.mdb.postgresql.v1.Resources\x12\x37\n\x04role\x18\x05 \x01(\x0e\x32).yandex.cloud.mdb.postgresql.v1.Host.Role\x12;\n\x06health\x18\x06 \x01(\x0e\x32+.yandex.cloud.mdb.postgresql.v1.Host.Health\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.yandex.cloud.mdb.postgresql.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x1a\n\x12replication_source\x18\t \x01(\t\x12-\n\x08priority\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12:\n\x06\x63onfig\x18\x0b \x01(\x0b\x32*.yandex.cloud.mdb.postgresql.v1.HostConfig\x12\x18\n\x10\x61ssign_public_ip\x18\x0c \x01(\x08\x12\x46\n\x0creplica_type\x18\r \x01(\x0e\x32\x30.yandex.cloud.mdb.postgresql.v1.Host.ReplicaType\"1\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06MASTER\x10\x01\x12\x0b\n\x07REPLICA\x10\x02\"H\n\x0bReplicaType\x12\x18\n\x14REPLICA_TYPE_UNKNOWN\x10\x00\x12\t\n\x05\x41SYNC\x10\x01\x12\x08\n\x04SYNC\x10\x02\x12\n\n\x06QUORUM\x10\x03\"M\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x0c\n\x08READONLY\x10\x04\"\xe4\x10\n\nHostConfig\x12y\n\x15postgresql_config_9_6\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig9_6H\x00R\x18postgresqlHostConfig_9_6\x12\x7f\n\x17postgresql_config_10_1c\x18\x04 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10_1CH\x00R\x1apostgresqlHostConfig_10_1c\x12v\n\x14postgresql_config_10\x18\x02 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig10H\x00R\x17postgresqlHostConfig_10\x12v\n\x14postgresql_config_11\x18\x03 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11H\x00R\x17postgresqlHostConfig_11\x12\x7f\n\x17postgresql_config_11_1c\x18\x06 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig11_1CH\x00R\x1apostgresqlHostConfig_11_1c\x12v\n\x14postgresql_config_12\x18\x05 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12H\x00R\x17postgresqlHostConfig_12\x12\x7f\n\x17postgresql_config_12_1c\x18\x07 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig12_1CH\x00R\x1apostgresqlHostConfig_12_1c\x12v\n\x14postgresql_config_13\x18\x08 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13H\x00R\x17postgresqlHostConfig_13\x12\x7f\n\x17postgresql_config_13_1c\x18\n \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig13_1CH\x00R\x1apostgresqlHostConfig_13_1c\x12v\n\x14postgresql_config_14\x18\t \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14H\x00R\x17postgresqlHostConfig_14\x12\x7f\n\x17postgresql_config_14_1c\x18\x0b \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig14_1CH\x00R\x1apostgresqlHostConfig_14_1c\x12v\n\x14postgresql_config_15\x18\x0c \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15H\x00R\x17postgresqlHostConfig_15\x12\x7f\n\x17postgresql_config_15_1c\x18\r \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig15_1CH\x00R\x1apostgresqlHostConfig_15_1c\x12v\n\x14postgresql_config_16\x18\x0e \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16H\x00R\x17postgresqlHostConfig_16\x12\x7f\n\x17postgresql_config_16_1c\x18\x0f \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig16_1CH\x00R\x1apostgresqlHostConfig_16_1c\x12v\n\x14postgresql_config_17\x18\x10 \x01(\x0b\x32=.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17H\x00R\x17postgresqlHostConfig_17\x12\x7f\n\x17postgresql_config_17_1c\x18\x11 \x01(\x0b\x32@.yandex.cloud.mdb.postgresql.v1.config.PostgresqlHostConfig17_1CH\x00R\x1apostgresqlHostConfig_17_1cB\x13\n\x11postgresql_config\"\x80\x02\n\x07Service\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.yandex.cloud.mdb.postgresql.v1.Service.Type\x12>\n\x06health\x18\x02 \x01(\x0e\x32..yandex.cloud.mdb.postgresql.v1.Service.Health\"8\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0e\n\nPOSTGRESQL\x10\x01\x12\n\n\x06POOLER\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08READONLY\x10\x03\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"m\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x0f\n\x07web_sql\x18\x02 \x01(\x08\x12\x12\n\nserverless\x18\x03 \x01(\x08\x12\x15\n\rdata_transfer\x18\x04 \x01(\x08\x12\x14\n\x0cyandex_query\x18\x05 \x01(\x08\"\x8d\x01\n\x16PerformanceDiagnostics\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12/\n\x1asessions_sampling_interval\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400\x12\x31\n\x1cstatements_sampling_interval\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-86400\"\x90\x01\n\x13\x44iskSizeAutoscaling\x12.\n\x17planned_usage_threshold\x18\x01 \x01(\x03\x42\r\xe8\xc7\x31\x00\xfa\xc7\x31\x05\x30-100\x12\x30\n\x19\x65mergency_usage_threshold\x18\x02 \x01(\x03\x42\r\xe8\xc7\x31\x00\xfa\xc7\x31\x05\x30-100\x12\x17\n\x0f\x64isk_size_limit\x18\x03 \x01(\x03\x42s\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.postgresql.v1.cluster_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"yandex.cloud.api.mdb.postgresql.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/postgresql/v1;postgresql'
  _globals['_CLUSTER_LABELSENTRY']._loaded_options = None
  _globals['_CLUSTER_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CLUSTERCONFIG'].fields_by_name['backup_retain_period_days']._loaded_options = None
  _globals['_CLUSTERCONFIG'].fields_by_name['backup_retain_period_days']._serialized_options = b'\372\3071\0047-60'
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['sessions_sampling_interval']._loaded_options = None
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['sessions_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['statements_sampling_interval']._loaded_options = None
  _globals['_PERFORMANCEDIAGNOSTICS'].fields_by_name['statements_sampling_interval']._serialized_options = b'\372\3071\0071-86400'
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['planned_usage_threshold']._loaded_options = None
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['planned_usage_threshold']._serialized_options = b'\350\3071\000\372\3071\0050-100'
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['emergency_usage_threshold']._loaded_options = None
  _globals['_DISKSIZEAUTOSCALING'].fields_by_name['emergency_usage_threshold']._serialized_options = b'\350\3071\000\372\3071\0050-100'
  _globals['_CLUSTER']._serialized_start=2176
  _globals['_CLUSTER']._serialized_end=3268
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=2960
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=3005
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=3007
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=3080
  _globals['_CLUSTER_HEALTH']._serialized_start=3082
  _globals['_CLUSTER_HEALTH']._serialized_end=3145
  _globals['_CLUSTER_STATUS']._serialized_start=3147
  _globals['_CLUSTER_STATUS']._serialized_end=3268
  _globals['_MONITORING']._serialized_start=3270
  _globals['_MONITORING']._serialized_end=3331
  _globals['_CLUSTERCONFIG']._serialized_start=3334
  _globals['_CLUSTERCONFIG']._serialized_end=5976
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=5979
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=6233
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_start=6145
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_end=6233
  _globals['_HOST']._serialized_start=6236
  _globals['_HOST']._serialized_end=6988
  _globals['_HOST_ROLE']._serialized_start=6786
  _globals['_HOST_ROLE']._serialized_end=6835
  _globals['_HOST_REPLICATYPE']._serialized_start=6837
  _globals['_HOST_REPLICATYPE']._serialized_end=6909
  _globals['_HOST_HEALTH']._serialized_start=6911
  _globals['_HOST_HEALTH']._serialized_end=6988
  _globals['_HOSTCONFIG']._serialized_start=6991
  _globals['_HOSTCONFIG']._serialized_end=9139
  _globals['_SERVICE']._serialized_start=9142
  _globals['_SERVICE']._serialized_end=9398
  _globals['_SERVICE_TYPE']._serialized_start=9277
  _globals['_SERVICE_TYPE']._serialized_end=9333
  _globals['_SERVICE_HEALTH']._serialized_start=9335
  _globals['_SERVICE_HEALTH']._serialized_end=9398
  _globals['_RESOURCES']._serialized_start=9400
  _globals['_RESOURCES']._serialized_end=9480
  _globals['_ACCESS']._serialized_start=9482
  _globals['_ACCESS']._serialized_end=9591
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_start=9594
  _globals['_PERFORMANCEDIAGNOSTICS']._serialized_end=9735
  _globals['_DISKSIZEAUTOSCALING']._serialized_start=9738
  _globals['_DISKSIZEAUTOSCALING']._serialized_end=9882
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/saml/federation_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/saml/federation_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.saml import federation_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2
from yandex.cloud.organizationmanager.v1 import user_account_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__account__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAyandex/cloud/organizationmanager/v1/saml/federation_service.proto\x12(yandex.cloud.organizationmanager.v1.saml\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/duration.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x39yandex/cloud/organizationmanager/v1/saml/federation.proto\x1a\x36yandex/cloud/organizationmanager/v1/user_account.proto\x1a\x1dyandex/cloud/validation.proto\"7\n\x14GetFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x9a\x01\n\x16ListFederationsRequest\x12%\n\x0forganization_id\x18\x06 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"}\n\x17ListFederationsResponse\x12I\n\x0b\x66\x65\x64\x65rations\x18\x01 \x03(\x0b\x32\x34.yandex.cloud.organizationmanager.v1.saml.Federation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xd2\x05\n\x17\x43reateFederationRequest\x12!\n\x0forganization_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x31\n\x04name\x18\x02 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x0e\x63ookie_max_age\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x05 \x01(\x08\x12\x1e\n\x06issuer\x18\x06 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\x07 \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\t \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\n \x01(\x08\x12\x9a\x01\n\x06labels\x18\x0b \x03(\x0b\x32M.yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18\x43reateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x88\x06\n\x17UpdateFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12>\n\x0e\x63ookie_max_age\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0b\xfa\xc7\x31\x07\x31\x30m-12h\x12$\n\x1c\x61uto_create_account_on_login\x18\x06 \x01(\x08\x12\x1e\n\x06issuer\x18\x07 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12J\n\x0bsso_binding\x18\x08 \x01(\x0e\x32\x35.yandex.cloud.organizationmanager.v1.saml.BindingType\x12\x1f\n\x07sso_url\x18\t \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12_\n\x11security_settings\x18\n \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.saml.FederationSecuritySettings\x12!\n\x19\x63\x61se_insensitive_name_ids\x18\x0c \x01(\x08\x12\x9a\x01\n\x06labels\x18\r \x03(\x0b\x32M.yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x0b\x10\x0c\"1\n\x18UpdateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\":\n\x17\x44\x65leteFederationRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"`\n\x1f\x41\x64\x64\x46\x65\x64\x65ratedUserAccountsRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1c\n\x08name_ids\x18\x02 \x03(\tB\n\x8a\xc8\x31\x06<=1000\"9\n AddFederatedUserAccountsMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"k\n AddFederatedUserAccountsResponse\x12G\n\ruser_accounts\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.UserAccount\"r\n\"DeleteFederatedUserAccountsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\'\n\x0bsubject_ids\x18\x02 \x03(\tB\x12\x82\xc8\x31\x06\x31-1000\x8a\xc8\x31\x04\x31-50\"<\n#DeleteFederatedUserAccountsMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"^\n#DeleteFederatedUserAccountsResponse\x12\x18\n\x10\x64\x65leted_subjects\x18\x01 \x03(\t\x12\x1d\n\x15non_existing_subjects\x18\x02 \x03(\t\"\xa2\x01\n ListFederatedUserAccountsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1010\"\x85\x01\n!ListFederatedUserAccountsResponse\x12G\n\ruser_accounts\x18\x01 \x03(\x0b\x32\x30.yandex.cloud.organizationmanager.v1.UserAccount\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x81\x01\n\x1fListFederationOperationsRequest\x12\x1f\n\rfederation_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"r\n ListFederationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xfb\x10\n\x11\x46\x65\x64\x65rationService\x12\xbe\x01\n\x03Get\x12>.yandex.cloud.organizationmanager.v1.saml.GetFederationRequest\x1a\x34.yandex.cloud.organizationmanager.v1.saml.Federation\"A\x82\xd3\xe4\x93\x02;\x12\x39/organization-manager/v1/saml/federations/{federation_id}\x12\xbe\x01\n\x04List\x12@.yandex.cloud.organizationmanager.v1.saml.ListFederationsRequest\x1a\x41.yandex.cloud.organizationmanager.v1.saml.ListFederationsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/organization-manager/v1/saml/federations\x12\xce\x01\n\x06\x43reate\x12\x41.yandex.cloud.organizationmanager.v1.saml.CreateFederationRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*&\n\x18\x43reateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02.\")/organization-manager/v1/saml/federations:\x01*\x12\xde\x01\n\x06Update\x12\x41.yandex.cloud.organizationmanager.v1.saml.UpdateFederationRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*&\n\x18UpdateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02>29/organization-manager/v1/saml/federations/{federation_id}:\x01*\x12\xe6\x01\n\x06\x44\x65lete\x12\x41.yandex.cloud.organizationmanager.v1.saml.DeleteFederationRequest\x1a!.yandex.cloud.operation.Operation\"v\xb2\xd2*1\n\x18\x44\x65leteFederationMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02;*9/organization-manager/v1/saml/federations/{federation_id}\x12\x9e\x02\n\x0f\x41\x64\x64UserAccounts\x12I.yandex.cloud.organizationmanager.v1.saml.AddFederatedUserAccountsRequest\x1a!.yandex.cloud.operation.Operation\"\x9c\x01\xb2\xd2*D\n AddFederatedUserAccountsMetadata\x12 AddFederatedUserAccountsResponse\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/saml/federations/{federation_id}:addUserAccounts:\x01*\x12\xad\x02\n\x12\x44\x65leteUserAccounts\x12L.yandex.cloud.organizationmanager.v1.saml.DeleteFederatedUserAccountsRequest\x1a!.yandex.cloud.operation.Operation\"\xa5\x01\xb2\xd2*J\n#DeleteFederatedUserAccountsMetadata\x12#DeleteFederatedUserAccountsResponse\x82\xd3\xe4\x93\x02Q\"L/organization-manager/v1/saml/federations/{federation_id}:deleteUserAccounts:\x01*\x12\xff\x01\n\x10ListUserAccounts\x12J.yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsRequest\x1aK.yandex.cloud.organizationmanager.v1.saml.ListFederatedUserAccountsResponse\"R\x82\xd3\xe4\x93\x02L\x12J/organization-manager/v1/saml/federations/{federation_id}:listUserAccounts\x12\xf5\x01\n\x0eListOperations\x12I.yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsRequest\x1aJ.yandex.cloud.organizationmanager.v1.saml.ListFederationOperationsResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/organization-manager/v1/saml/federations/{federation_id}/operationsB\x81\x01\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.saml.federation_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n,yandex.cloud.api.organizationmanager.v1.samlZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/saml;saml'
  _globals['_GETFEDERATIONREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_GETFEDERATIONREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFEDERATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['cookie_max_age']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['cookie_max_age']._serialized_options = b'\372\3071\00710m-12h'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['sso_url']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['sso_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEFEDERATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['cookie_max_age']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['cookie_max_age']._serialized_options = b'\372\3071\00710m-12h'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['issuer']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['sso_url']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['sso_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEFEDERATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEFEDERATIONREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_DELETEFEDERATIONREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['name_ids']._loaded_options = None
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['name_ids']._serialized_options = b'\212\3101\006<=1000'
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['subject_ids']._loaded_options = None
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['subject_ids']._serialized_options = b'\202\3101\0061-1000\212\3101\0041-50'
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1010'
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['federation_id']._loaded_options = None
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['federation_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTFEDERATIONOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_FEDERATIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002;\0229/organization-manager/v1/saml/federations/{federation_id}'
  _globals['_FEDERATIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002+\022)/organization-manager/v1/saml/federations'
  _globals['_FEDERATIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateFederationMetadata\022\nFederation\202\323\344\223\002.\")/organization-manager/v1/saml/federations:\001*'
  _globals['_FEDERATIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateFederationMetadata\022\nFederation\202\323\344\223\002>29/organization-manager/v1/saml/federations/{federation_id}:\001*'
  _globals['_FEDERATIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteFederationMetadata\022\025google.protobuf.Empty\202\323\344\223\002;*9/organization-manager/v1/saml/federations/{federation_id}'
  _globals['_FEDERATIONSERVICE'].methods_by_name['AddUserAccounts']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['AddUserAccounts']._serialized_options = b'\262\322*D\n AddFederatedUserAccountsMetadata\022 AddFederatedUserAccountsResponse\202\323\344\223\002N\"I/organization-manager/v1/saml/federations/{federation_id}:addUserAccounts:\001*'
  _globals['_FEDERATIONSERVICE'].methods_by_name['DeleteUserAccounts']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['DeleteUserAccounts']._serialized_options = b'\262\322*J\n#DeleteFederatedUserAccountsMetadata\022#DeleteFederatedUserAccountsResponse\202\323\344\223\002Q\"L/organization-manager/v1/saml/federations/{federation_id}:deleteUserAccounts:\001*'
  _globals['_FEDERATIONSERVICE'].methods_by_name['ListUserAccounts']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['ListUserAccounts']._serialized_options = b'\202\323\344\223\002L\022J/organization-manager/v1/saml/federations/{federation_id}:listUserAccounts'
  _globals['_FEDERATIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_FEDERATIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002F\022D/organization-manager/v1/saml/federations/{federation_id}/operations'
  _globals['_GETFEDERATIONREQUEST']._serialized_start=427
  _globals['_GETFEDERATIONREQUEST']._serialized_end=482
  _globals['_LISTFEDERATIONSREQUEST']._serialized_start=485
  _globals['_LISTFEDERATIONSREQUEST']._serialized_end=639
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_start=641
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_end=766
  _globals['_CREATEFEDERATIONREQUEST']._serialized_start=769
  _globals['_CREATEFEDERATIONREQUEST']._serialized_end=1491
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=1446
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1491
  _globals['_CREATEFEDERATIONMETADATA']._serialized_start=1493
  _globals['_CREATEFEDERATIONMETADATA']._serialized_end=1542
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_start=1545
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_end=2321
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=1446
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1491
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_start=2323
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_end=2372
  _globals['_DELETEFEDERATIONREQUEST']._serialized_start=2374
  _globals['_DELETEFEDERATIONREQUEST']._serialized_end=2432
  _globals['_DELETEFEDERATIONMETADATA']._serialized_start=2434
  _globals['_DELETEFEDERATIONMETADATA']._serialized_end=2483
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST']._serialized_start=2485
  _globals['_ADDFEDERATEDUSERACCOUNTSREQUEST']._serialized_end=2581
  _globals['_ADDFEDERATEDUSERACCOUNTSMETADATA']._serialized_start=2583
  _globals['_ADDFEDERATEDUSERACCOUNTSMETADATA']._serialized_end=2640
  _globals['_ADDFEDERATEDUSERACCOUNTSRESPONSE']._serialized_start=2642
  _globals['_ADDFEDERATEDUSERACCOUNTSRESPONSE']._serialized_end=2749
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST']._serialized_start=2751
  _globals['_DELETEFEDERATEDUSERACCOUNTSREQUEST']._serialized_end=2865
  _globals['_DELETEFEDERATEDUSERACCOUNTSMETADATA']._serialized_start=2867
  _globals['_DELETEFEDERATEDUSERACCOUNTSMETADATA']._serialized_end=2927
  _globals['_DELETEFEDERATEDUSERACCOUNTSRESPONSE']._serialized_start=2929
  _globals['_DELETEFEDERATEDUSERACCOUNTSRESPONSE']._serialized_end=3023
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST']._serialized_start=3026
  _globals['_LISTFEDERATEDUSERACCOUNTSREQUEST']._serialized_end=3188
  _globals['_LISTFEDERATEDUSERACCOUNTSRESPONSE']._serialized_start=3191
  _globals['_LISTFEDERATEDUSERACCOUNTSRESPONSE']._serialized_end=3324
  _globals['_LISTFEDERATIONOPERATIONSREQUEST']._serialized_start=3327
  _globals['_LISTFEDERATIONOPERATIONSREQUEST']._serialized_end=3456
  _globals['_LISTFEDERATIONOPERATIONSRESPONSE']._serialized_start=3458
  _globals['_LISTFEDERATIONOPERATIONSRESPONSE']._serialized_end=3572
  _globals['_FEDERATIONSERVICE']._serialized_start=3575
  _globals['_FEDERATIONSERVICE']._serialized_end=5746
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Lock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _State:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Lock._State.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATE_UNSPECIFIED: Lock._State.ValueType  # 0
        UNLOCKED: Lock._State.ValueType  # 1
        """Subscription unlocked."""
        LOCKED: Lock._State.ValueType  # 2
        """Subscription locked to the resource."""
        DELETED: Lock._State.ValueType  # 3
        """Subscription lock deleted."""

    class State(_State, metaclass=_StateEnumTypeWrapper): ...
    STATE_UNSPECIFIED: Lock.State.ValueType  # 0
    UNLOCKED: Lock.State.ValueType  # 1
    """Subscription unlocked."""
    LOCKED: Lock.State.ValueType  # 2
    """Subscription locked to the resource."""
    DELETED: Lock.State.ValueType  # 3
    """Subscription lock deleted."""

    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TEMPLATE_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the subscription lock."""
    instance_id: builtins.str
    """ID of the subscription instance."""
    resource_id: builtins.str
    """ID of the resource."""
    state: global___Lock.State.ValueType
    """Subscription lock state."""
    template_id: builtins.str
    """ID of the subscription template."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the start of the subscription lock."""

    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp of the end of the subscription lock."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Update timestamp."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        resource_id: builtins.str = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        state: global___Lock.State.ValueType = ...,
        template_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "end_time", b"end_time", "start_time", b"start_time", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "end_time", b"end_time", "id", b"id", "instance_id", b"instance_id", "resource_id", b"resource_id", "start_time", b"start_time", "state", b"state", "template_id", b"template_id", "updated_at", b"updated_at"]) -> None: ...

global___Lock = Lock



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/api/v1/agent_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/api/v1/agent_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.loadtesting.api.v1.agent import agent_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_agent__pb2
from yandex.cloud.loadtesting.api.v1.agent import create_compute_instance_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_create__compute__instance__pb2
from yandex.cloud.loadtesting.api.v1.agent import log_settings_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_agent_dot_log__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/api/v1/agent_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x31yandex/cloud/loadtesting/api/v1/agent/agent.proto\x1a\x43yandex/cloud/loadtesting/api/v1/agent/create_compute_instance.proto\x1a\x38yandex/cloud/loadtesting/api/v1/agent/log_settings.proto\x1a\x1dyandex/cloud/validation.proto\"\x84\x04\n\x12\x43reateAgentRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=54\x12/\n\x04name\x18\x02 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12]\n\x17\x63ompute_instance_params\x18\x04 \x01(\x0b\x32<.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance\x12\x15\n\ragent_version\x18\x05 \x01(\t\x12\x8c\x01\n\x06labels\x18\x06 \x03(\x0b\x32?.yandex.cloud.loadtesting.api.v1.CreateAgentRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12H\n\x0clog_settings\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.loadtesting.api.v1.agent.LogSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13\x43reateAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"#\n\x0fGetAgentRequest\x12\x10\n\x08\x61gent_id\x18\x02 \x01(\t\"&\n\x12\x44\x65leteAgentRequest\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"\'\n\x13\x44\x65leteAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t\"\x8e\x01\n\x11ListAgentsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=54\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"v\n\x12ListAgentsResponse\x12<\n\x06\x61gents\x18\x01 \x03(\x0b\x32,.yandex.cloud.loadtesting.api.v1.agent.Agent\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\xd1\x03\n\x12UpdateAgentRequest\x12\x16\n\x08\x61gent_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12/\n\x04name\x18\x03 \x01(\tB!\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12]\n\x17\x63ompute_instance_params\x18\x05 \x01(\x0b\x32<.yandex.cloud.loadtesting.api.v1.agent.CreateComputeInstance\x12\x8c\x01\n\x06labels\x18\x06 \x03(\x0b\x32?.yandex.cloud.loadtesting.api.v1.UpdateAgentRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13UpdateAgentMetadata\x12\x10\n\x08\x61gent_id\x18\x01 \x01(\t2\xe3\x06\n\x0c\x41gentService\x12\xac\x01\n\x06\x43reate\x12\x33.yandex.cloud.loadtesting.api.v1.CreateAgentRequest\x1a!.yandex.cloud.operation.Operation\"J\xb2\xd2*\"\n\x13\x43reateAgentMetadata\x12\x0b\x61gent.Agent\x82\xd3\xe4\x93\x02\x1e\"\x19/loadtesting/api/v1/agent:\x01*\x12\x93\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.api.v1.GetAgentRequest\x1a,.yandex.cloud.loadtesting.api.v1.agent.Agent\",\x82\xd3\xe4\x93\x02&\x12$/loadtesting/api/v1/agent/{agent_id}\x12\x92\x01\n\x04List\x12\x32.yandex.cloud.loadtesting.api.v1.ListAgentsRequest\x1a\x33.yandex.cloud.loadtesting.api.v1.ListAgentsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/loadtesting/api/v1/agent\x12\xbe\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.loadtesting.api.v1.DeleteAgentRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*,\n\x13\x44\x65leteAgentMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02&*$/loadtesting/api/v1/agent/{agent_id}\x12\xb7\x01\n\x06Update\x12\x33.yandex.cloud.loadtesting.api.v1.UpdateAgentRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*\"\n\x13UpdateAgentMetadata\x12\x0b\x61gent.Agent\x82\xd3\xe4\x93\x02)2$/loadtesting/api/v1/agent/{agent_id}:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.agent_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _globals['_CREATEAGENTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEAGENTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEAGENTREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATEAGENTREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=54'
  _globals['_CREATEAGENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEAGENTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_CREATEAGENTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEAGENTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEAGENTREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEAGENTREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_LISTAGENTSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTAGENTSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=54'
  _globals['_LISTAGENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAGENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTAGENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAGENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTAGENTSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAGENTSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTAGENTSRESPONSE'].fields_by_name['next_page_token']._loaded_options = None
  _globals['_LISTAGENTSRESPONSE'].fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_UPDATEAGENTREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['agent_id']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEAGENTREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_AGENTSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*\"\n\023CreateAgentMetadata\022\013agent.Agent\202\323\344\223\002\036\"\031/loadtesting/api/v1/agent:\001*'
  _globals['_AGENTSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/loadtesting/api/v1/agent/{agent_id}'
  _globals['_AGENTSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/loadtesting/api/v1/agent'
  _globals['_AGENTSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteAgentMetadata\022\025google.protobuf.Empty\202\323\344\223\002&*$/loadtesting/api/v1/agent/{agent_id}'
  _globals['_AGENTSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*\"\n\023UpdateAgentMetadata\022\013agent.Agent\202\323\344\223\002)2$/loadtesting/api/v1/agent/{agent_id}:\001*'
  _globals['_CREATEAGENTREQUEST']._serialized_start=436
  _globals['_CREATEAGENTREQUEST']._serialized_end=952
  _globals['_CREATEAGENTREQUEST_LABELSENTRY']._serialized_start=907
  _globals['_CREATEAGENTREQUEST_LABELSENTRY']._serialized_end=952
  _globals['_CREATEAGENTMETADATA']._serialized_start=954
  _globals['_CREATEAGENTMETADATA']._serialized_end=993
  _globals['_GETAGENTREQUEST']._serialized_start=995
  _globals['_GETAGENTREQUEST']._serialized_end=1030
  _globals['_DELETEAGENTREQUEST']._serialized_start=1032
  _globals['_DELETEAGENTREQUEST']._serialized_end=1070
  _globals['_DELETEAGENTMETADATA']._serialized_start=1072
  _globals['_DELETEAGENTMETADATA']._serialized_end=1111
  _globals['_LISTAGENTSREQUEST']._serialized_start=1114
  _globals['_LISTAGENTSREQUEST']._serialized_end=1256
  _globals['_LISTAGENTSRESPONSE']._serialized_start=1258
  _globals['_LISTAGENTSRESPONSE']._serialized_end=1376
  _globals['_UPDATEAGENTREQUEST']._serialized_start=1379
  _globals['_UPDATEAGENTREQUEST']._serialized_end=1844
  _globals['_UPDATEAGENTREQUEST_LABELSENTRY']._serialized_start=907
  _globals['_UPDATEAGENTREQUEST_LABELSENTRY']._serialized_end=952
  _globals['_UPDATEAGENTMETADATA']._serialized_start=1846
  _globals['_UPDATEAGENTMETADATA']._serialized_end=1885
  _globals['_AGENTSERVICE']._serialized_start=1888
  _globals['_AGENTSERVICE']._serialized_end=2755
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/compute/v1/reserved_instance_pool_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/compute/v1/reserved_instance_pool_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud.compute.v1 import reserved_instance_pool_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_reserved__instance__pool__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/compute/v1/reserved_instance_pool_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a.yandex/cloud/compute/v1/instance_service.proto\x1a\x34yandex/cloud/compute/v1/reserved_instance_pool.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\"Q\n\x1eGetReservedInstancePoolRequest\x12/\n\x19reserved_instance_pool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xba\x01\n ListReservedInstancePoolsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x8c\x01\n!ListReservedInstancePoolsResponse\x12N\n\x17reserved_instance_pools\x18\x01 \x03(\x0b\x32-.yandex.cloud.compute.v1.ReservedInstancePool\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc2\x05\n!CreateReservedInstancePoolRequest\x12\x33\n\x04name\x18\x01 \x01(\tB%\xf2\xc7\x31!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x03 \x03(\x0b\x32\x46.yandex.cloud.compute.v1.CreateReservedInstancePoolRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1d\n\x07zone_id\x18\x04 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1f\n\tfolder_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0bplatform_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12:\n\x0cgpu_settings\x18\x08 \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12=\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32%.yandex.cloud.compute.v1.BootDiskSpec\x12\x42\n\x10network_settings\x18\n \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x1b\n\x04size\x18\x0b \x01(\x03\x42\r\xfa\xc7\x31\t0-1048576\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n\"CreateReservedInstancePoolMetadata\x12!\n\x19reserved_instance_pool_id\x18\x01 \x01(\t\"\xc4\x03\n!UpdateReservedInstancePoolRequest\x12/\n\x19reserved_instance_pool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x33\n\x04name\x18\x03 \x01(\tB%\xf2\xc7\x31!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9b\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.compute.v1.UpdateReservedInstancePoolRequest.LabelsEntryBC\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x1c\x12\x14[a-z][-_./\\@0-9a-z]*\x1a\x04\x31-63\x12\x1b\n\x04size\x18\x06 \x01(\x03\x42\r\xfa\xc7\x31\t0-1048576\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"G\n\"UpdateReservedInstancePoolMetadata\x12!\n\x19reserved_instance_pool_id\x18\x01 \x01(\t\"T\n!DeleteReservedInstancePoolRequest\x12/\n\x19reserved_instance_pool_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"G\n\"DeleteReservedInstancePoolMetadata\x12!\n\x19reserved_instance_pool_id\x18\x01 \x01(\t\"$\n\"DeleteReservedInstancePoolResponse2\xc6\x08\n\x1bReservedInstancePoolService\x12\xb4\x01\n\x03Get\x12\x37.yandex.cloud.compute.v1.GetReservedInstancePoolRequest\x1a-.yandex.cloud.compute.v1.ReservedInstancePool\"E\x82\xd3\xe4\x93\x02?\x12=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.compute.v1.ListReservedInstancePoolsRequest\x1a:.yandex.cloud.compute.v1.ListReservedInstancePoolsResponse\")\x82\xd3\xe4\x93\x02#\x12!/compute/v1/reservedInstancePools\x12\xd3\x01\n\x06\x43reate\x12:.yandex.cloud.compute.v1.CreateReservedInstancePoolRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*:\n\"CreateReservedInstancePoolMetadata\x12\x14ReservedInstancePool\x82\xd3\xe4\x93\x02&\"!/compute/v1/reservedInstancePools:\x01*\x12\xf0\x01\n\x06Update\x12:.yandex.cloud.compute.v1.UpdateReservedInstancePoolRequest\x1a!.yandex.cloud.operation.Operation\"\x86\x01\xb2\xd2*:\n\"UpdateReservedInstancePoolMetadata\x12\x14ReservedInstancePool\x82\xd3\xe4\x93\x02\x42\x32=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}:\x01*\x12\xfb\x01\n\x06\x44\x65lete\x12:.yandex.cloud.compute.v1.DeleteReservedInstancePoolRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*H\n\"DeleteReservedInstancePoolMetadata\x12\"DeleteReservedInstancePoolResponse\x82\xd3\xe4\x93\x02?*=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}Bb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.reserved_instance_pool_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _globals['_GETRESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._loaded_options = None
  _globals['_GETRESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST'].fields_by_name['order_by']._serialized_options = b'\212\3101\005<=100'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['zone_id']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['zone_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['platform_id']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['platform_id']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['resources_spec']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['resources_spec']._serialized_options = b'\350\3071\001'
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['size']._loaded_options = None
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['size']._serialized_options = b'\372\3071\t0-1048576'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071!|[a-z]([-_a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\017[-_./\\@0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\034\022\024[a-z][-_./\\@0-9a-z]*\032\0041-63'
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['size']._loaded_options = None
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['size']._serialized_options = b'\372\3071\t0-1048576'
  _globals['_DELETERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._loaded_options = None
  _globals['_DELETERESERVEDINSTANCEPOOLREQUEST'].fields_by_name['reserved_instance_pool_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002?\022=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}'
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/compute/v1/reservedInstancePools'
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*:\n\"CreateReservedInstancePoolMetadata\022\024ReservedInstancePool\202\323\344\223\002&\"!/compute/v1/reservedInstancePools:\001*'
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*:\n\"UpdateReservedInstancePoolMetadata\022\024ReservedInstancePool\202\323\344\223\002B2=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}:\001*'
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_RESERVEDINSTANCEPOOLSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*H\n\"DeleteReservedInstancePoolMetadata\022\"DeleteReservedInstancePoolResponse\202\323\344\223\002?*=/compute/v1/reservedInstancePools/{reserved_instance_pool_id}'
  _globals['_GETRESERVEDINSTANCEPOOLREQUEST']._serialized_start=400
  _globals['_GETRESERVEDINSTANCEPOOLREQUEST']._serialized_end=481
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST']._serialized_start=484
  _globals['_LISTRESERVEDINSTANCEPOOLSREQUEST']._serialized_end=670
  _globals['_LISTRESERVEDINSTANCEPOOLSRESPONSE']._serialized_start=673
  _globals['_LISTRESERVEDINSTANCEPOOLSRESPONSE']._serialized_end=813
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST']._serialized_start=816
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST']._serialized_end=1522
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_start=1477
  _globals['_CREATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_end=1522
  _globals['_CREATERESERVEDINSTANCEPOOLMETADATA']._serialized_start=1524
  _globals['_CREATERESERVEDINSTANCEPOOLMETADATA']._serialized_end=1595
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST']._serialized_start=1598
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST']._serialized_end=2050
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_start=1477
  _globals['_UPDATERESERVEDINSTANCEPOOLREQUEST_LABELSENTRY']._serialized_end=1522
  _globals['_UPDATERESERVEDINSTANCEPOOLMETADATA']._serialized_start=2052
  _globals['_UPDATERESERVEDINSTANCEPOOLMETADATA']._serialized_end=2123
  _globals['_DELETERESERVEDINSTANCEPOOLREQUEST']._serialized_start=2125
  _globals['_DELETERESERVEDINSTANCEPOOLREQUEST']._serialized_end=2209
  _globals['_DELETERESERVEDINSTANCEPOOLMETADATA']._serialized_start=2211
  _globals['_DELETERESERVEDINSTANCEPOOLMETADATA']._serialized_end=2282
  _globals['_DELETERESERVEDINSTANCEPOOLRESPONSE']._serialized_start=2284
  _globals['_DELETERESERVEDINSTANCEPOOLRESPONSE']._serialized_end=2320
  _globals['_RESERVEDINSTANCEPOOLSERVICE']._serialized_start=2323
  _globals['_RESERVEDINSTANCEPOOLSERVICE']._serialized_end=3417
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/loadtesting/agent/v1/agent_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/loadtesting/agent/v1/agent_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/loadtesting/agent/v1/agent_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb9\x02\n\x17\x43laimAgentStatusRequest\x12\x19\n\x11\x61gent_instance_id\x18\x01 \x01(\t\x12Q\n\x06status\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest.Status\x12\x16\n\x0estatus_message\x18\x03 \x01(\t\"\x97\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eREADY_FOR_TEST\x10\x01\x12\x12\n\x0ePREPARING_TEST\x10\x02\x12\x0b\n\x07TESTING\x10\x03\x12\x0f\n\x0bTANK_FAILED\x10\x04\x12\x0b\n\x07STOPPED\x10\x05\x12\x17\n\x13UPLOADING_ARTIFACTS\x10\x06\x12\t\n\x05\x45RROR\x10\x07\"(\n\x18\x43laimAgentStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\xb1\x01\n\x16ReportEventLogsRequest\x12\'\n\x11\x61gent_instance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12%\n\x0fidempotency_key\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=36\x12G\n\x06\x65vents\x18\x03 \x03(\x0b\x32+.yandex.cloud.loadtesting.agent.v1.EventLogB\n\x82\xc8\x31\x06<=1000\"\x19\n\x17ReportEventLogsResponse\"\x84\x03\n\x08\x45ventLog\x12\x1f\n\x07message\x18\x01 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=2000\x12\x46\n\x08severity\x18\x02 \x01(\x0e\x32\x34.yandex.cloud.loadtesting.agent.v1.EventLog.Severity\x12\x33\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12K\n\x08metadata\x18\x04 \x03(\x0b\x32\x39.yandex.cloud.loadtesting.agent.v1.EventLog.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\\\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\t\n\x05\x44\x45\x42UG\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\t\n\x05\x46\x41TAL\x10\x05\x32\xb8\x03\n\x0c\x41gentService\x12\xcf\x01\n\x0b\x43laimStatus\x12:.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusRequest\x1a;.yandex.cloud.loadtesting.agent.v1.ClaimAgentStatusResponse\"G\x82\xd3\xe4\x93\x02\x41\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\x01*\x12\xd5\x01\n\x0fReportEventLogs\x12\x39.yandex.cloud.loadtesting.agent.v1.ReportEventLogsRequest\x1a:.yandex.cloud.loadtesting.agent.v1.ReportEventLogsResponse\"K\x82\xd3\xe4\x93\x02\x45\"@/loadtesting/agent/v1/agents/{agent_instance_id}/reportEventLogs:\x01*Bt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.agent_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['agent_instance_id']._loaded_options = None
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['agent_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['idempotency_key']._loaded_options = None
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['idempotency_key']._serialized_options = b'\350\3071\001\212\3101\004<=36'
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['events']._loaded_options = None
  _globals['_REPORTEVENTLOGSREQUEST'].fields_by_name['events']._serialized_options = b'\202\3101\006<=1000'
  _globals['_EVENTLOG_METADATAENTRY']._loaded_options = None
  _globals['_EVENTLOG_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTLOG'].fields_by_name['message']._loaded_options = None
  _globals['_EVENTLOG'].fields_by_name['message']._serialized_options = b'\350\3071\001\212\3101\006<=2000'
  _globals['_EVENTLOG'].fields_by_name['timestamp']._loaded_options = None
  _globals['_EVENTLOG'].fields_by_name['timestamp']._serialized_options = b'\350\3071\001'
  _globals['_AGENTSERVICE'].methods_by_name['ClaimStatus']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['ClaimStatus']._serialized_options = b'\202\323\344\223\002A\"</loadtesting/agent/v1/agents/{agent_instance_id}/claimStatus:\001*'
  _globals['_AGENTSERVICE'].methods_by_name['ReportEventLogs']._loaded_options = None
  _globals['_AGENTSERVICE'].methods_by_name['ReportEventLogs']._serialized_options = b'\202\323\344\223\002E\"@/loadtesting/agent/v1/agents/{agent_instance_id}/reportEventLogs:\001*'
  _globals['_CLAIMAGENTSTATUSREQUEST']._serialized_start=187
  _globals['_CLAIMAGENTSTATUSREQUEST']._serialized_end=500
  _globals['_CLAIMAGENTSTATUSREQUEST_STATUS']._serialized_start=349
  _globals['_CLAIMAGENTSTATUSREQUEST_STATUS']._serialized_end=500
  _globals['_CLAIMAGENTSTATUSRESPONSE']._serialized_start=502
  _globals['_CLAIMAGENTSTATUSRESPONSE']._serialized_end=542
  _globals['_REPORTEVENTLOGSREQUEST']._serialized_start=545
  _globals['_REPORTEVENTLOGSREQUEST']._serialized_end=722
  _globals['_REPORTEVENTLOGSRESPONSE']._serialized_start=724
  _globals['_REPORTEVENTLOGSRESPONSE']._serialized_end=749
  _globals['_EVENTLOG']._serialized_start=752
  _globals['_EVENTLOG']._serialized_end=1140
  _globals['_EVENTLOG_METADATAENTRY']._serialized_start=999
  _globals['_EVENTLOG_METADATAENTRY']._serialized_end=1046
  _globals['_EVENTLOG_SEVERITY']._serialized_start=1048
  _globals['_EVENTLOG_SEVERITY']._serialized_end=1140
  _globals['_AGENTSERVICE']._serialized_start=1143
  _globals['_AGENTSERVICE']._serialized_end=1583
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/datasphere/v1/project.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/datasphere/v1/project.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(yandex/cloud/datasphere/v1/project.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xf3\x03\n\x07Project\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x08settings\x18\x06 \x01(\x0b\x32,.yandex.cloud.datasphere.v1.Project.Settings\x12:\n\x06limits\x18\x07 \x01(\x0b\x32*.yandex.cloud.datasphere.v1.Project.Limits\x1ay\n\x08Settings\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x61ta_proc_cluster_id\x18\x03 \x01(\t\x12\x1a\n\x12security_group_ids\x18\x05 \x03(\tJ\x04\x08\x04\x10\x05\x1a\x7f\n\x06Limits\x12\x37\n\x12max_units_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12<\n\x17max_units_per_execution\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueBk\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.project_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _globals['_PROJECT']._serialized_start=138
  _globals['_PROJECT']._serialized_end=637
  _globals['_PROJECT_SETTINGS']._serialized_start=387
  _globals['_PROJECT_SETTINGS']._serialized_end=508
  _globals['_PROJECT_LIMITS']._serialized_start=510
  _globals['_PROJECT_LIMITS']._serialized_end=637
# @@protoc_insertion_point(module_scope)
